function [x,u,z,t]=dcolpi(v,tf);
% [x,u,z,t]=dcolpi(v,tf);
% Purpose:
% Simulate the distillation column with multivariable PI control.
% On input
% v   the disturbance time series, 
%     v=[R^1 V^1; R^2 V^2; ...; R^N V^N]
%     i.e. a (N x 2) matrix where N is the number of samples.
% tf  final time. This function simulate the system from t=0 to t=tf.
%     Default is tf=400 if not specified.

if nargin == 1; tf=400; end
if tf < 0
 disp('ERROR: final time should be positive');
 return;
end
N=length(v);
if N > 1
 t=0:(N-1); t=t'; t=t*tf/(N-1);
else
 disp('WARNING: number of samples (N) should satisfy N > 1');
 return;
end

% Get steady state compositions, inputs and disturbances
[x0,u0,v0]=ssprof([2;2.5],[1.0;0.5],0);
%
% Get linearized model matrices
[a,b,c,d]=fx2abcd(x0,u0,v0);
%
% Multivariable PI-controller
at=[a;d]; at=[at,zeros(10,2)]; bt=[b;zeros(2,2)];
q=diag([10^5,0,0,0,0,0,0,10^4,200,20]); p=diag([1,1]);
g=lqr(at,bt,q,p); g=-g; g1=g(:,1:8); g2=g(:,9:10);
%
% Closed loop system from setpoint (xs) and disturb. (v) to outputs [x;z]
ac=[a+b*g1,b*g2;d,zeros(2,2)]; bc=[c,-(a+b*g1);zeros(2,2),-d];
dc=eye(10);                    ec=zeros(10,10);
%
xs=x0*ones(1,N); xs=xs';
us=u0*ones(1,N); us=us';
vs=v0*ones(1,N); vs=vs';
dv=v-vs;
yc=lsim(ac,bc,dc,ec,[dv,xs],t,[x0;0;0]);
%
x=yc(:,1:8); z=yc(:,9:10);
dx=x-xs;
du=g1*dx'+g2*z'; u=du'+us;

subplot(211), plot(t,x(:,1))
grid
xlabel('[s]');
ylabel('x1');
title('x1: Bottom product composition')
%
subplot(212), plot(t,x(:,8))
grid
xlabel('[s]');
ylabel('x8');
title('x8: Top product composition')

