function [Y,X,T]=kolsim(U,V,x,dt);
% [Y,X,t]=kolsim(U,V,x0,dt)
% Purpose:
% Simulate the distillation column for control input time series (U) and
% disturbance time series (V).
% On input:
% U  = [R_1 V_1; R_2 V_2; ...; R_N V_N]      
%    U is a (N x 2) matrix. N is the number of discrete time instants,
%    i.e. the first row in U is the control inputs to the column at time t=1.
%    The control inputs is the reflux (R) and the steam flowrate (boilup) (V).
%    The initial time is fixed to t=1.
% V  = [F_1 xf_1; F_2 xf_2; ...; F_N xf_N]    
%    V is a (N x 2) matrix where N is the number of discrete time instants,
%    i.e. the first row in V is the disturbances to the column at time t=1.
%    The disturbances is the feed flowrate (F) and the feed composition (xf).
%    The initial time is fixed to t=1.
% x0 Initial values for the (n=8) compositions (states). A reasonable initial
%    composition profile is determined by, x0=ssprof(U(1,:)',V(1,:)'); or
%    x0=ssprof([R;V],[F;xf]);. This is the default profile for x if not specified.
% dt The step lenght used by the backward Euler integration method, dt=t_k+1-t_k
%    Default, dt=0.3, if not specified in the call.
% On output
% Y  =[y1_1 y2_1; y1_2 y2_2; ...; y1_N y2_N]
% X  =[x1_1 ... x8_1; x1_2 ... x8_2; ...; x1_N ... x8_N]
% T  =[t_1; t_2; t_3; ...; t_N]
% Functions called: fcol

%
% Check inputs
if nargin == 3; dt=0.3; end
if nargin == 2; dt=0.3; x=ssprof(U(1,1:2)',V(1,1:2)'); end
[Nu,r]=size(U); [Nv,p]=size(V);
N=min(Nu,Nv);
[n,m]=size(x);
if (n < 8) | (n > 8)
   disp('ERROR: x not of dim. 8, The number of states should be n=8');
 return;
end

%
T = 0; t=0;          % initial time
X = x';              % initial compositions
Y =[x(1),x(8)];      % initial bottom and top compositions, measurements
%
for it=1:N
  u=U(it,:)';
  v=V(it,:)';
  f = fcol(x,u,v);
  x = x + dt*f;
  t = t + dt;
% storing the time series
  T = [T;t];
  X = [X;x'];
  Y = [Y;[x(1),x(8)]];
end

subplot(211), plot(T,Y(:,1))
grid
xlabel('[s]')
ylabel('y_1')
title('y_1: bottom product composition')
%
subplot(212), plot(T,Y(:,2))
grid
xlabel('[s]')
ylabel('y_2')
title('y_2: top product composition')
